@@ -267,8 +267,7 @@ class BatchProcessor:
         # else:
         # logger.info(f"No pending items found")
         return False
-    
-    
+
 
     def execute_one_throttled_batch_item(self):
         """
@@ -354,7 +353,7 @@ class BatchProcessor:
         return out
 
     def get_status(self):
-        status = {"type": self.db.get_type_counts(), "status": self.db.get_status_counts(), "last": self.db.get_last_jobs(limit=10), "type_status": self.db.get_type_status_counts(), "counts": self.get_job_counts()}
+        status = {"bob": "lol", "type": self.db.get_type_counts(), "status": self.db.get_status_counts(), "last": self.db.get_last_jobs(limit=10), "type_status": self.db.get_type_status_counts(), "counts": self.get_job_counts()}
         return status
 
     def process(self):
